@@ -1,8 +1,7 @@
 #
-#   dmi.py - class to wrap DMI Table information
-#
 #   Copyright 2009 - 2013   Clark Williams <williams@redhat.com>
 #   Copyright 2009 - 2013   David Sommerseth <davids@redhat.com>
+#   Copyright 2022          John Kacur <jkacur@redhat.com>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -24,6 +23,7 @@
 #   including keys needed to generate an equivalently functional executable
 #   are deemed to be part of the source code.
 #
+""" dmi.py class to wrap DMI Table Information """
 
 import sys
 import os
@@ -35,14 +35,19 @@ from rteval import rtevalConfig
 
 try:
     import dmidecode
-    dmidecode_loaded = True
+    dmidecode_avail = True
 except ModuleNotFoundError:
-    dmidecode_loaded = False
+    dmidecode_avail = False
 
-def ProcessWarnings():
+def set_dmidecode_avail(val):
+    """ Used to set global variable dmidecode_avail from a function """
+    global dmidecode_avail
+    dmidecode_avail = val
+
+def ProcessWarnings(logger=None):
     """ Process Warnings from dmidecode """
 
-    if not dmidecode_loaded:
+    if not dmidecode_avail:
         return
 
     if not hasattr(dmidecode, 'get_warnings'):
@@ -52,16 +57,19 @@ def ProcessWarnings():
     if warnings is None:
         return
 
+    ignore1  = '/dev/mem: Permission denied'
+    ignore2 = 'No SMBIOS nor DMI entry point found, sorry.'
+    ignore3 = 'Failed to open memory buffer (/dev/mem): Permission denied'
+    ignore = (ignore1, ignore2, ignore3)
     for warnline in warnings.split('\n'):
         # Ignore these warnings, as they are "valid" if not running as root
-        if warnline == '/dev/mem: Permission denied':
-            continue
-        if warnline == 'No SMBIOS nor DMI entry point found, sorry.':
+        if warnline in ignore:
             continue
 
         # All other warnings will be printed
         if len(warnline) > 0:
-            print("** DMI WARNING ** %s" % warnline)
+            logger.log(Log.DEBUG, f"** DMI WARNING ** {warnline}")
+            set_dmidecode_avail(False)
 
     dmidecode.clear_warnings()
 
@@ -69,12 +77,12 @@ def ProcessWarnings():
 class DMIinfo:
     '''class used to obtain DMI info via python-dmidecode'''
 
-    # TODO: Remove unnecessary config
-    def __init__(self, config, logger):
-        self.__version = '0.5'
+    def __init__(self, logger=None):
+        self.__version = '0.6'
+        self._log = logger
 
-        if not dmidecode_loaded:
-            logger.log(Log.DEBUG|Log.WARN, "No dmidecode module found, ignoring DMI tables")
+        if not dmidecode_avail:
+            logger.log(Log.DEBUG, "DMI info unavailable, ignoring DMI tables")
             self.__fake = True
             return
 
@@ -83,22 +91,24 @@ class DMIinfo:
 
         self.__xsltparser = self.__load_xslt('rteval_dmi.xsl')
 
-    def __load_xslt(self, fname):
-        xsltfile = None
+    @staticmethod
+    def __load_xslt(fname):
+        xsltf = None
         if os.path.exists(fname):
-            xsltfile = open(fname, "r")
-        elif rtevalConfig.default_config_search([fname], os.path.isfile):
-            xsltfile = open(rtevalConfig.default_config_search([fname], os.path.isfile), "r")
+            xsltf = fname
+        else:
+            xsltf = rtevalConfig.default_config_search([fname], os.path.isfile)
 
-        if xsltfile:
-            xsltdoc = lxml.etree.parse(xsltfile)
-            ret = lxml.etree.XSLT(xsltdoc)
-            xsltfile.close()
+        if xsltf:
+            with open(xsltf, "r") as xsltfile:
+                xsltdoc = lxml.etree.parse(xsltfile)
+                ret = lxml.etree.XSLT(xsltdoc)
             return ret
 
         raise RuntimeError(f'Could not locate XSLT template for DMI data ({fname})')
 
     def MakeReport(self):
+        """ Add DMI information to final report """
         rep_n = libxml2.newNode("DMIinfo")
         rep_n.newProp("version", self.__version)
         if self.__fake:
@@ -106,14 +116,25 @@ class DMIinfo:
             rep_n.newProp("not_available", "1")
         else:
             self.__dmixml.SetResultType(dmidecode.DMIXML_DOC)
-            dmiqry = xmlout.convert_libxml2_to_lxml_doc(self.__dmixml.QuerySection('all'))
+            try:
+                dmiqry = xmlout.convert_libxml2_to_lxml_doc(self.__dmixml.QuerySection('all'))
+            except Exception as ex1:
+                self._log.log(Log.DEBUG, f'** EXCEPTION {str(ex1)}, will query BIOS only')
+                try:
+                    # If we can't query 'all', at least query 'bios'
+                    dmiqry = xmlout.convert_libxml2_to_lxml_doc(self.__dmixml.QuerySection('bios'))
+                except Exception as ex2:
+                    rep_n.addContent("No DMI tables available")
+                    rep_n.newProp("not_available", "1")
+                    self._log.log(Log.DEBUG, f'** EXCEPTION {str(ex2)}, dmi info will not be reported')
+                    return rep_n
             resdoc = self.__xsltparser(dmiqry)
             dmi_n = xmlout.convert_lxml_to_libxml2_nodes(resdoc.getroot())
             rep_n.addChild(dmi_n)
         return rep_n
 
 def unit_test(rootdir):
-    """ unit_test for dmi.py, looks a little crufty! """
+    """ unit_test for dmi.py """
 
     class UnittestConfigDummy:
         def __init__(self, rootdir):
@@ -125,22 +146,22 @@ def unit_test(rootdir):
                 self.__dict__[k] = self.config[k]
 
     try:
-        ProcessWarnings()
+        log = Log()
+        log.SetLogVerbosity(Log.DEBUG|Log.INFO)
+
+        ProcessWarnings(logger=log)
         if os.getuid() != 0:
             print("** ERROR **  Must be root to run this unit_test()")
             return 1
 
-        log = Log()
-        log.SetLogVerbosity(Log.DEBUG|Log.INFO)
-        cfg = UnittestConfigDummy(rootdir)
-        d = DMIinfo(cfg, log)
+        d = DMIinfo(logger=log)
         dx = d.MakeReport()
         x = libxml2.newDoc("1.0")
         x.setRootElement(dx)
         x.saveFormatFileEnc("-", "UTF-8", 1)
         return 0
     except Exception as e:
-        print("** EXCEPTION: %s" % str(e))
+        print(f"** EXCEPTION: {str(e)}")
         return 1
 
 if __name__ == '__main__':
